@@ -362,7 +362,7 @@ class PSquared(object):
         raise FatalError('Configuration "' + name + '" is not available from "' + application.find('uri').text  + '"', 1, ET.tostring(application))
 
 
-    def _prepare_query(self, options = None):
+    def _prepare_query(self, options):
         query = ''
         if None != options and 0 != len(options):
             conjunction = '?'
@@ -371,7 +371,7 @@ class PSquared(object):
         return query
 
 
-    def get_configuration(self, name, options = None):
+    def get_configuration(self, name, **kwargs):
         """:param str name: the name of the configuration that should be returned.
         :param options: an optional dictionary of options determining how much detail to include in the returned configuration.
 
@@ -382,7 +382,7 @@ class PSquared(object):
         """
 
         configuration_url, application = self._get_configuration_url(name)
-        url_to_use = configuration_url + self._prepare_query(options)
+        url_to_use = configuration_url + self._prepare_query(kwargs)
         r = self.session.get(url_to_use)
         _check_status(url_to_use, r, 200)
         configuration = ET.fromstring(r.text)
@@ -390,7 +390,7 @@ class PSquared(object):
         return configuration, application
 
 
-    def get_version(self, config, vers = None, options = None):
+    def get_version(self, config, vers = None, **kwargs):
         """:param str config: the name of the configuration who version should be returned.
         :param str vers: the name of the version of the specified configuration to be returned.
         :param options: an optional dictionary of options determining how much detail to include in the returned version.
@@ -420,7 +420,7 @@ class PSquared(object):
         if None == version_element:
             raise FatalError('Version "' + vers_to_use + '" of configuration "' + config + '" is not available from ' + url, 1, None)
         version_url = version_element.find('uri').text
-        url_to_use = version_url + self._prepare_query(options)
+        url_to_use = version_url + self._prepare_query(kwargs)
         r = self.session.get(url_to_use)
         _check_status(url_to_use, r, 200)
         version = ET.fromstring(r.text)
